Installation — MARV Robotics 21.10.0 documentation

# Installation

There are two modes of installation. One is based on Docker the other installs MARV Robotics natively on your system. It might be a good idea to read both and decide then.

- Docker
  - Prerequisites
  - Building or configure image used
  - Start container
  - Adding your own code
  - Serve documentation
  - Summary
- Native
  - Prerequisites
  - System dependencies
  - MARV Robotics
  - Build and serve documentation
  - Summary